{ pkgs, inputs, lib, ... }:

{
  imports = [
    # inputs.impermanence.nixosModules.home-manager.impermanence

    ../../modules/stylix/home
    ../../modules/editors/nixvim
    ../../modules/shells/zsh.nix

    ../../modules/programs/dunst.nix
    ../../modules/programs/waybar
    ../../modules/programs/hyprpaper.nix
    ../../modules/programs/tofi.nix
    ../../modules/programs/alacritty.nix
    ../../modules/programs/firefox.nix
    ../../modules/programs/tmux.nix
    ../../modules/programs/mangohud.nix

    (import ../../modules/window-managers/hyprland {
      monitors = [
        "DP-2, 1920x1080@240, 1080x300, 1"
        "HDMI-A-1, 1920x1080@144, 0x0, 1, transform, 1"
      ];

      border-radius = 4;
    })

    ../../modules/window-managers/hyprland/hyprlock.nix
    ../../modules/window-managers/hyprland/hypridle.nix

    # (import ../../modules/disko/impermanence-home.nix {
    #   extraDirectories = [
    #     ".jump"
    #
    #     ".mozilla"
    #     ".zen"
    #
    #     ".config/vesktop"
    #     ".config/zsh"
    #
    #     ".cache/mozilla"
    #     ".cache/zen"
    #     ".cache/nvidia"
    #     ".cache/nix"
    #     ".cache/obexd"
    #     ".factorio"
    #     ".local/share/Steam"
    #   ];
    #   extraFiles = [ ];
    #
    #   username = "snorre";
    #   nixIndexEnabled = true;
    # })
  ];

  home.username = "snorre";
  home.homeDirectory = "/home/snorre";

  stylix.base16Scheme = "${pkgs.base16-schemes}/share/themes/gruvbox-material-dark-soft.yaml";
  stylix.polarity = "dark";
  stylix.image = ./nixos-wallpaper.png;
  stylix.autoEnable = true;
  stylix.targets.alacritty.enable = true;
  # hyprpaper.wallpaper = ./nixos-wallpaper.png;

  nixpkgs.config.allowUnfree = true;

  home.packages =
    let
      tex = (pkgs.texlive.combine {
        inherit (pkgs.texlive) scheme-medium
          titling
          biblatex hyperref amsmath tcolorbox environ
          ;
      });
    in
    (with pkgs; [
      file
      nixpkgs-fmt
      ripgrep
      jump
      wl-clipboard
      hyprpaper
      hyprpicker
      grimblast
      tofi
      brightnessctl
      # Required for waybar to work
      playerctl
      wl-clipboard

      localsend

      ipe
      texlivePackages.latex
      texlivePackages.luatex
      zathura
      tex
      biber

      prismlauncher

      spotify
      vesktop
      sublime-merge

      obs-studio

      vial

      path-of-building
    ]);

  # Mount 2tb harddisk
  systemd.user.mounts."home-snorre-2tb" = {
    Unit = {
      Description = "Mount 2tb hdd to home folder";
    };

    Mount = {
      What = "/dev/sda1";
      Where = "/home/snorre/2tb";
      Type = "ext4";
      Options = "defaults";
      TimeoutSec = 30;
    };
  };

  programs.btop.enable = true;

  # programs.nix-index = {
  #   enable = true;
  #   enableZshIntegration = true;
  # };

  zsh.jump.enable = true;
  zsh.jump.show-destination = true;
  # Since zsh is the login shell it overrides $HOME/.zsh_history before impermanence can restore the old version.
  # Therefore we simply store the history directly in /persist
  zsh.histFile = "/persist/system/home/snorre/.zsh_history";

  # Let home-manager manage itself
  programs.home-manager.enable = true;

  home.sessionVariables = {
    EDITOR = "nvim";
    # NIX_AUTO_RUN = "1"; # Automatically run non-installed commands if possible
    # NIX_BUILD_SHELL = "zsh";
  };

  home.stateVersion = "23.11";
}
