{ config, pkgs, inputs, ... }:

{
  imports = [
    inputs.impermanence.nixosModules.home-manager.impermanence

    ../../modules/stylix/home
    ../../modules/editors/nixvim
    ../../modules/shells/zsh.nix

    ../../modules/programs/dunst.nix
    ../../modules/programs/waybar
    ../../modules/programs/hyprpaper.nix

    ../../modules/programs/tofi.nix
    ../../modules/programs/alacritty.nix
    ../../modules/programs/tmux.nix
    # ../../modules/programs/firefox.nix

    ../../modules/window-managers/hyprland
    ../../modules/window-managers/hyprland/hyprlock.nix
    ../../modules/window-managers/hyprland/hypridle.nix

    # (import ../../modules/disko/impermanence-home.nix {
    #   extraDirectories = [
    #     ".jump"
    #     ".android"
    #     ".mozilla"
    #     ".zen"
    #
    #     ".config/zsh"
    #     ".config/unity3d"
    #
    #     # Required for android studio to not reset every time i reboot
    #     ".config/Google"
    #     ".cache/Google"
    #
    #     ".cache/mozilla"
    #     ".cache/nvidia"
    #     ".cache/nix"
    #     ".cache/zen"
    #     {
    #       directory = ".gradle";
    #       method = "symlink";
    #     }
    #     {
    #       directory = "Android";
    #       method = "symlink";
    #     }
    #   ];
    #   extraFiles = [
    #   ];
    #
    #   username = "work";
    #   nixIndexEnabled = true;
    # })
  ];

  home.username = "work";
  home.homeDirectory = "/home/work";

  stylix.base16Scheme = "${pkgs.base16-schemes}/share/themes/gruvbox-material-dark-soft.yaml";
  stylix.polarity = "dark";

  stylix.image = ./nixos-wallpaper.png;
  hyprpaper.wallpaper = ./nixos-wallpaper.png;

  nixpkgs.config.allowUnfree = true;

  # Man, i love unity workarounds in my system config
  # nixpkgs.config.permittedInsecurePackages = [
  #   "openssl-1.1.1w"
  # ];

  home.packages = with pkgs; [
    file
    nixpkgs-fmt
    ripgrep
    jump
    hyprpaper
    wl-clipboard
    grimblast
    tofi
    # Required for waybar to work
    playerctl

    zoom-us

    # (unityhub.override {
    #   extraLibs = pkgs: with pkgs; [
    #     openssl_1_1 # Unity doesnt like secure versions of openssl
    #   ];
    # })
    # Vscode is neccesary ~for~ _to make_ unity to generate .csproj files
    # vscode
    #
    inputs.zen-browser.packages."${system}".default

    sublime-merge
    # android-studio
    slack
    spotify
  ];

  stylix.targets.alacritty.enable = true;

  programs.btop.enable = true;
  programs.mangohud.enable = true;

  zsh.jump.enable = true;
  zsh.jump.show-destination = true;
  # zsh.histFile = "/persist/home/work/.zsh_history";

  # xdg.desktopEntries = {
  #   unityhub = {
  #     name = "Unity Hub";
  #     genericName = "Game Engine";
  #     exec = builtins.toString (pkgs.writeShellScript "start_unity_hub.sh" ''
  #       #! /usr/bin/env nix-shell
  #       #! nix-shell -i bash -p vscode
  #       ${pkgs.unityhub}/opt/unityhub/unityhub %U
  #     '');
  #     terminal = false;
  #     type = "Application";
  #     categories = [ "Development" ];
  #     icon = "unityhub";
  #     # tryExec = "unityhub"; 
  #     mimeType = [ "x-scheme-handler/unityhub" ];
  #   };
  # };

  # Let home-manager manage itself
  programs.home-manager.enable = true;

  home.sessionVariables = {
    EDITOR = "nvim";
    # NIX_AUTO_RUN = "1"; # Automatically run non-installed commands if possible
  };

  home.stateVersion = "23.11";
}
